# processamento_imagem_pack

Description. 
The package processamento_imagem_pack is used to:
	Processing:
		- Histogam matching
		- Structural similarity
		- Resize image 
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install processamento_imagem_pack
```

## Author
Lucas Henrique

## License
[MIT](https://choosealicense.com/licenses/mit/)